@@ -172,6 +172,15 @@ class SteamApp(object):
         tool_manifest_path = install_path / "toolmanifest.vdf"
         try:
             tool_manifest_content = tool_manifest_path.read_text()
+
+            if tool_manifest_content == "":
+                logger.warning(
+                    "Tool manifest for %s is empty. You may need to reinstall "
+                    "the application.",
+                    name
+                )
+                return None
+
             tool_manifest = vdf.loads(tool_manifest_content)
             required_tool_appid = \
                 tool_manifest["manifest"].get("require_tool_appid", None)
@@ -745,9 +754,12 @@ def get_custom_windows_shortcuts(steam_path):
         shortcut_data = lower_dict(shortcut_data)
         shortcut_id = int(shortcut_id)
 
-        appid = get_appid_from_shortcut(
-            target=shortcut_data["exe"], name=shortcut_data["appname"]
-        )
+        if "appid" in shortcut_data:
+            appid = shortcut_data["appid"] & 0xffffffff
+        else:
+            appid = get_appid_from_shortcut(
+                target=shortcut_data["exe"], name=shortcut_data["appname"]
+            )
 
         prefix_path = \
             steam_path / "steamapps" / "compatdata" / str(appid) / "pfx"
@@ -781,7 +793,7 @@ def _link_tool_apps(steam_apps):
     for steam_app in steam_apps:
         if steam_app.required_tool_appid:
             steam_app.required_tool_app = \
-                appid2steam_app[steam_app.required_tool_appid]
+                appid2steam_app.get(steam_app.required_tool_appid)
 
 
 def get_steam_apps(steam_root, steam_path, steam_lib_paths):
