@@ -47,26 +47,49 @@ def get_host_library_paths():
     return ":".join(paths)
 
 
+RUNTIME_ROOT_GLOB_PATTERNS = (
+    "var/*/files/",
+    "*/files/"
+)
+
+
 def get_runtime_library_paths(steam_runtime_path, proton_app):
     """
     Get LD_LIBRARY_PATH value to run a command using Steam Runtime
     """
-    if proton_app.required_tool_app:
+    def find_runtime_app_root(runtime_app):
+        """
+        Find the runtime root (the directory containing the root fileystem
+        used for the container) for separately installed Steam Runtime app
+        """
+        for pattern in RUNTIME_ROOT_GLOB_PATTERNS:
+            try:
+                return next(
+                    runtime_app.install_path.glob(pattern)
+                )
+            except StopIteration:
+                pass
+
+        raise RuntimeError(
+            "Could not find Steam Runtime runtime root for {}".format(
+                runtime_app.name
+            )
+        )
+
+    if proton_app.required_tool_appid:
         # bwrap based Steam Runtime is used for Proton installations that
         # use separate Steam runtimes
         # TODO: Try to run the Wine binaries inside an user namespace somehow.
         # Newer Steam Runtime environments may rely on a newer glibc than what
         # is available on the host system, which may cause potential problems
         # otherwise.
-        runtime_root = next(
-            proton_app.required_tool_app.install_path.glob("*/files/")
-        )
+        runtime_root = find_runtime_app_root(proton_app.required_tool_app)
         return "".join([
             str(proton_app.install_path / "dist" / "lib"), os.pathsep,
             str(proton_app.install_path / "dist" / "lib64"), os.pathsep,
             get_host_library_paths(), os.pathsep,
-            str(runtime_root / "i686-pc-linux-gnu" / "lib"), os.pathsep,
-            str(runtime_root / "x86_64-pc-linux-gnu" / "lib")
+            str(runtime_root / "lib" / "i386-linux-gnu"), os.pathsep,
+            str(runtime_root / "lib" / "x86_64-linux-gnu")
         ])
 
     # Traditional LD_LIBRARY_PATH based Steam Runtime is used otherwise
@@ -159,6 +182,17 @@ def run_command(
 
     If 'steam_runtime_path' is provided, run the command using Steam Runtime
     """
+    # Check for incomplete Steam Runtime installation
+    runtime_install_incomplete = \
+        proton_app.required_tool_appid and not proton_app.required_tool_app
+
+    if steam_runtime_path and runtime_install_incomplete:
+        raise RuntimeError(
+            "{} is missing the required Steam Runtime. You may need to launch "
+            "a Steam app using this Proton version to finish the "
+            "installation.".format(proton_app.name)
+        )
+
     # Make a copy of the environment variables to restore later
     environ_copy = os.environ.copy()
 
